Understanding our workflow
==========================

**High level documentation workflow**

1. Identify a documentation change.

   - *Typos:* please go ahead and fix it (or report as a bug).
   - *Open issues:* leave a note in the issue comments that you
     are working on the issue.
   - *New documentation:* open an issue with your idea or suggestion. We'll
     review the issue and work with you to identify next steps.

2. Update the source file.

3. Commit the change.

4. Test changes locally.

5. Open a pull request.

6. Check response of automated tests.

   - If tests pass: Nice job. Wait for reviewer feedback and/
     or your pull request to be merged.

   - If tests show an error: Revise and resubmit your pull
     request. You do not need to open a new pull request. If needed, please
     ask for assistance.

7. Celebrate your documentation contribution.

8. Repeat. If you would like suggestions for a new
   documentation issue to work on, please ask.


Thanks for contributing!